@@ -15,6 +15,11 @@ from . import (
     validation,  # moved out of the way to not obscure the flow
 )
 
+# Dunder (underscore-prefixed) options are ones
+# we don't advertise for direct usage, specific to a narrow set of policies.
+# We'd rather have users build up upon policies we ship that set them.
+
+
 # Defaults of integer property values (doubles as an allowlist)
 
 INT_DEFAULTS = dict.fromkeys((
@@ -22,7 +27,7 @@ INT_DEFAULTS = dict.fromkeys((
     'min_dh_size', 'min_dsa_size', 'min_rsa_size',
     'sha1_in_certs',
     'ssh_certs',
-), 0) | {'min_ec_size': 256}
+), 0)
 
 
 # For enum values, first value works as default,
@@ -43,8 +48,7 @@ ALL_SCOPES = (  # defined explicitly to catch typos / globbing nothing
     'ipsec', 'ike', 'libreswan',
     'kerberos', 'krb5',
     'dnssec', 'bind',
-    # sequoia scope is intentionally omitted
-    'rpm', 'rpm-sequoia',
+    'sequoia', 'rpm', 'rpm-sequoia',
 )
 DUMPABLE_SCOPES = {  # TODO: fix duplication, backends specify same things
     'bind': {'bind', 'dnssec'},
@@ -57,6 +61,7 @@ DUMPABLE_SCOPES = {  # TODO: fix duplication, backends specify same things
     'openssh-client': {'openssh-client', 'openssh', 'ssh'},
     'openssh-server': {'openssh-server', 'openssh', 'ssh'},
     'openssl': {'openssl', 'tls', 'ssl'},
+    'sequoia': {'sequoia'},
     'rpm': {'rpm', 'rpm-sequoia'},
 }
 
@@ -237,13 +242,12 @@ def syntax_check_line(line, warn=False):
         warnings.warn(ex)
 
 
-class PolicySyntaxDeprecationWarning(FutureWarning):
-    def __init__(self, deprecated, replacement, what='option', onetoone=False):
+class PolicySyntaxDeprecationWarning(FutureWarning, validation.PolicyWarning):
+    def __init__(self, deprecated, replacement):
         replacement = replacement.replace('\n', ' and ')
-        msg = f'{what} {deprecated} is deprecated'
-        msg += f', please rewrite your rules using {replacement}'
-        if not onetoone:
-            msg += '; be advised that it is not always a 1-1 replacement'
+        msg = f'option {deprecated} is deprecated'
+        msg += f', please rewrite your rules using {replacement}; '
+        msg += 'be advised that it is not always a 1-1 replacement'
         super().__init__(msg)
 
 
@@ -311,20 +315,6 @@ def preprocess_text(text):
             warnings.warn(PolicySyntaxDeprecationWarning(match_fr, match_to))
         text = re.sub(regex, to, text)
 
-    VALUE_REPLACEMENTS = {
-        'X25519-MLKEM768': 'MLKEM768-X25519',  # RHEL-99813
-    }
-    for fr, to in VALUE_REPLACEMENTS.items():
-        regex = r'\b' + fr + r'\b'
-        matches = {}
-        for match in re.finditer(regex, text):
-            matches[match.group(0)] = re.sub(regex, to, match.group(0))
-        for match_fr, match_to in matches.items():
-            warnings.warn(PolicySyntaxDeprecationWarning(match_fr, match_to,
-                                                         what='value',
-                                                         onetoone=True))
-        text = re.sub(regex, to, text)
-
     dtls_versions = list(alg_lists.DTLS_PROTOCOLS[::-1])
     while dtls_versions:
         neg = " ".join("-" + v for v in dtls_versions[:-1])
